import { Injector } from '../common/di/index';
import { Entity, EntityState } from '../entity/index';
import { Repository } from '../repository/index';
import { UIState } from '../uistate/index';
import { Form } from '../form/index';
import { StateMachine } from '../state-machine/index';
import { Command, CommandBus } from '../command/index';
import { ViewModelNode } from './viewmodel-node';
/**
 * 视图模型
 */
declare abstract class ViewModel extends ViewModelNode {
    [action: string]: any;
    /**
     * 实体状态
     */
    entityState: EntityState<Entity> | null;
    /**
     * UI状态
     */
    uiState: UIState | null;
    /**
     * 表单
     */
    form: Form | null;
    /**
     * 状态机
     */
    stateMachine: StateMachine | null;
    /**
     * 实体仓库
     */
    respository: Repository<Entity> | null;
    /**
     * 命令总线
     */
    commandBus: CommandBus | null;
    /**
     * 构造函数
     */
    constructor(injector: Injector);
    /**
     * 初始化
     */
    init(): void;
    /**
     * 派发命令
     */
    dispatch(command: Command): any;
    /**
     * 注销
     */
    dispose(): void;
}
export { ViewModel };
